#!/usr/bin/python
#
# sawmodel_extract - Extract unfolding forces from WLC-fitted data.
#
# Copyright (C) 2008-2009, William Trevor King
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# The author may be contacted at <wking@drexel.edu> on the Internet, or
# write to Trevor King, Drexel University, Physics Dept., 3141 Chestnut St.,
# Philadelphia PA 19104, USA.

import sys
import sawmodel.fit_xml as fit_xml

def main():
    if len(sys.argv) <= 1:
        print """usage: extract_unfolds.py unfold.xml"

Where the unfolding files are of the format output be fit_xml.py
(e.g. the output of a cut_gui.py run.)"""
        sys.exit(1)
    
    listfilename = sys.argv[1]
    unfoldModels = fit_xml.readUnfoldList(listfilename)
    unfolds = []
    print "#Tail Index\tPosition (nm)\tForce (pN)\tL (nm)\tDelta L (nm)\tPost Delta L (nm)\tStiffness (pN/nm)\tDatafile"
    for model in unfoldModels:
        model.load()
        model.fit()
        if len(model.WLClist) >= 1 and model.selected == True:
            fitUnfolds = model.getUnfolds()
            ln=len(fitUnfolds)
            prev_L = None
            for i,point in enumerate(fitUnfolds):
                wlc = model.WLClist[i]
                if prev_L == None:
                    delta_L = '-'
                else:
                    delta_L = '%.4g' % ((wlc.L - prev_L)*1e9)
                if i+1 >= len(model.WLClist):
                    post_delta_L = '-'
                else:
                    post_delta_L = '%.4g' \
                        % ((model.WLClist[i+1].L - wlc.L)*1e9)
                min,max = model.getMinMax(i)
                dx = 0.01*(max[0]-min[0])
                dy = wlc.WLC(max[0]) - wlc.WLC(max[0]-dx)
                stiffness = dy/dx
                print "%d\t%.4g\t%.4g\t%.4g\t%s\t%s\t%.4g\t%s" \
                    % (ln-i-1, point[0]*1e9, point[1]*1e12, wlc.L*1e9,
                       delta_L, post_delta_L, stiffness, model.datafile)
                prev_L = wlc.L
            unfolds.extend(fitUnfolds)
        model.free()
    return 0

if __name__ == "__main__":
    main()
