"""sawmodel: tools for selecting and fitting sawtooth unfolding curves.

Requires
  * Matplotlib	(http://matplotlib.sourceforge.net/)
  * quickhull2d (http://www.physics.drexel.edu/~wking/code/python/quickhull2d-0.1.tar.gz)
"""

classifiers = """\
Development Status :: 2 - Pre-Alpha
Intended Audience :: Developers
Intended Audience :: Science/Research
Operating System :: OS Independent
License :: OSI Approved :: GNU General Public License (GPL)
Programming Language :: Python
Topic :: Scientific/Engineering
Topic :: Software Development :: Libraries :: Python Modules
"""

# http://peak.telecommunity.com/DevCenter/setuptools#using-setuptools-without-bundling-it
import ez_setup
ez_setup.use_setuptools()

from setuptools import setup, find_packages

# patch distutils if it can't cope with the "classifiers" or
# "download_url" keywords
from sys import version
if version < '2.2.3':
    from distutils.dist import DistributionMetadata
    DistributionMetadata.classifiers = None
    DistributionMetadata.download_url = None

import sawmodel
VERSION = sawmodel.VERSION

doclines = __doc__.split("\n")

setup(name="sawmodel",
      version=VERSION,
      maintainer="W. Trevor King",
      maintainer_email="wking@drexel.edu",
      url = "http://www.physics.drexel.edu/~wking/code/python/",
      download_url = "http://www.physics.drexel.edu/~wking/code/python/sawmodel-%s.tar.gz" % VERSION,
      license = "GNU General Public License (GPL)",
      platforms = ["all"],
      description = doclines[0],
      long_description = "\n".join(doclines[2:]),
      classifiers = filter(None, classifiers.split("\n")),
      py_modules = ['ez_setup'],
      packages = find_packages(),
      entry_points = { # automatic script generation
        'console_scripts': [
            'sawmodel_select = sawmodel.script.select:main',
            'sawmodel_select2xml = sawmodel.script.select2xml:main',
            'sawmodel_mark = sawmodel.script.mark:main',
            'sawmodel_enforce_policy = sawmodel.script.enforce_policy:main',
            'sawmodel_extract = sawmodel.script.extract:main',
            ],
        },
      install_requires = "quickhull2d",
      dependency_links = [
        "http://www.physics.drexel.edu/~wking/code/python"]
      )

# use packages to include subdirectory packages
# use py_modules to include single-module packages
# use ext_modules to include extension modules
# see
#   http://www.python.org/doc/2.5.2/dist/listing-modules.html
#   http://www.python.org/doc/2.5.2/dist/describing-extensions.html
